@@ -28,11 +28,13 @@ class ServerlessVPN:
 
     @property
     def localImage(self):
-        return 'registry.cn-hangzhou.aliyuncs.com/aliyunfc/vpn-local-proxy:v0.0.1'
+        region = self.config['region']
+        return 'registry.{}.aliyuncs.com/aliyunfc/vpn-local-proxy:v0.0.1'.format(region)
 
     @property
     def fcImage(self):
-        return 'registry.cn-hangzhou.aliyuncs.com/aliyunfc/vpn-fc-proxy:v0.0.1'
+        region = self.config['region']
+        return 'registry.{}.aliyuncs.com/aliyunfc/vpn-fc-proxy:v0.0.1'.format(region)
 
     def initTsClt(self):
         ak_id = self.config['akId']
